## Contributing

### You can do this!
We've tagged a number of issues as [you can do this!](/../../labels/you%20can%20do%20this%21). These will generally not require much (or any!) working knowledge of our SDK.

If you decide you want to help, that [you can do this!](/../../labels/you%20can%20do%20this%21) tag is a good place to start. Now, here's how you can actually get going:

- Follow the directions from [2. Create a fork/branch.](#2-create-a-forkbranch) to setup your environment.
- Find an issue that speaks to you, and comment in it "I've got this" or something like that 😄.
- If the issue isn't clear enough, feel free to tag in sdk team `@RevenueCat/sdk` asking for clarification.
- Work on the issue! 
- If that builds, then follow [the final steps (Create a pull request to RevenueCat)](#5-create-a-pull-request-to-revenuecatmain-and-request-review)
- Done!

## Environment Setup

#### 1. Create an issue to make sure its something that should be done.

Before submitting a Github issue, please make sure to

- Search for [existing Github issues](/../../issues)
- Review our [Help Center](https://support.revenuecat.com/hc/en-us)
- Read our [docs.revenuecat.com](https://docs.revenuecat.com/)

#### 2. Create a fork/branch.

#### 3. Do your work.

Be sure to adhere to the prevailing style of the project.

#### 4. Write tests for your fix/new functionality.

#### 5. Create a pull request to revenuecat/main and request review

Explain in your pull request the work that was done, the reasoning, and that tests passed.

#### 6. Make changes in response to review

#### 7. Bask in the glory of community maintained software
